==> eiffelstudio-16.05.tar: F_code/C16/id790.c <==
/*
 * Code for class ID_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "id790.h"
#include "eif_built_in.h"
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ID_AS}.initialize */
void F1466_16852 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("initialize", 1465, Current, 0, 1, 23221);
	RTGC;
	RTHOOK(1);
	tr1 = F613_5392(Current);
	F667_6671(RTCW(tr1), arg1);
	RTHOOK(2);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCV(F613_5392(Current))+ _LNGOFF_2_1_0_0_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_) = (EIF_INTEGER_32) ti4_1;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {ID_AS}.initialize_from_id */
void F1466_16853 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("initialize_from_id", 1465, Current, 0, 1, 23222);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_) = (EIF_INTEGER_32) arg1;
	RTHOOK(2);
	RTEE;
}

/* {ID_AS}.set_name */
void F1466_16854 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_name", 1465, Current, 0, 1, 23223);
	RTHOOK(1);
	F1466_16852(Current, arg1);
	RTHOOK(2);
	RTEE;
}

/* {ID_AS}.to_upper */
void F1466_16856 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_BOOLEAN loc4 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_8 tc1;
	EIF_CHARACTER_8 tc2;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("to_upper", 1465, Current, 4, 0, 23225);
	RTGC;
	RTHOOK(1);
	loc2 = *(EIF_REFERENCE *)(RTCV(F1466_16861(Current)));
	RTHOOK(2);
	loc3 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc2);
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 2L));
	for (;;) {
		RTHOOK(3);
		if ((EIF_BOOLEAN) (loc3 < ((EIF_INTEGER_32) 0L))) break;
		RTHOOK(4);
		/* INLINED CODE (SPECIAL.item) */
		tc2 = *((EIF_CHARACTER_8 *)loc2 + (loc3));
		/* END INLINED CODE */
		loc1 = tc2;
		RTHOOK(5);
		tc1 = (EIF_CHARACTER_8) toupper(loc1);
		if ((EIF_BOOLEAN)(loc1 != tc1)) {
			RTHOOK(6);
			loc4 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(7);
			loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
		} else {
			RTHOOK(8);
			loc3--;
		}
	}
	RTHOOK(9);
	if (loc4) {
		RTHOOK(10);
		tr1 = F1466_16861(Current);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7996[Dtype(tr1)-1150])(RTCW(tr1));
		F1466_16852(Current, tr1);
	}
	RTHOOK(11);
	RTLE;
	RTEE;
}

/* {ID_AS}.to_lower */
void F1466_16857 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_BOOLEAN loc4 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_8 tc1;
	EIF_CHARACTER_8 tc2;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("to_lower", 1465, Current, 4, 0, 23226);
	RTGC;
	RTHOOK(1);
	loc2 = *(EIF_REFERENCE *)(RTCV(F1466_16861(Current)));
	RTHOOK(2);
	loc3 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc2);
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 2L));
	for (;;) {
		RTHOOK(3);
		if ((EIF_BOOLEAN) (loc3 < ((EIF_INTEGER_32) 0L))) break;
		RTHOOK(4);
		/* INLINED CODE (SPECIAL.item) */
		tc2 = *((EIF_CHARACTER_8 *)loc2 + (loc3));
		/* END INLINED CODE */
		loc1 = tc2;
		RTHOOK(5);
		tc1 = (EIF_CHARACTER_8) tolower(loc1);
		if ((EIF_BOOLEAN)(loc1 != tc1)) {
			RTHOOK(6);
			loc4 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(7);
			loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
		} else {
			RTHOOK(8);
			loc3--;
		}
	}
	RTHOOK(9);
	if (loc4) {
		RTHOOK(10);
		tr1 = F1466_16861(Current);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7995[Dtype(tr1)-1150])(RTCW(tr1));
		F1466_16852(Current, tr1);
	}
	RTHOOK(11);
	RTLE;
	RTEE;
}

/* {ID_AS}.name_id */
EIF_INTEGER_32 F1466_16858 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_);
}


/* {ID_AS}.name_32 */
EIF_REFERENCE F1466_16859 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("name_32", 1465, Current, 0, 0, 23228);
	RTGC;
	RTHOOK(1);
	tr1 = F666_6658(Current);
	tr2 = F1466_16861(Current);
	Result = F1197_11532(RTCW(tr1), tr2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ID_AS}.name */
EIF_REFERENCE F1466_16861 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("name", 1465, Current, 1, 0, 23230);
	RTGC;
	RTHOOK(1);
	tr1 = F613_5392(Current);
	tr1 = F667_6668(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_));
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(2);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) loc1;
	} else {
		RTHOOK(4);
		Result = RTMS_EX_H("_Invalid_name",13,1140441701);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {ID_AS}.process */
void F1466_16862 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process", 1465, Current, 0, 1, 23231);
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3801[Dtype(arg1)-505])(RTCW(arg1), Current);
	RTHOOK(2);
	RTEE;
}

/* {ID_AS}.is_detachable_expression */
EIF_BOOLEAN F1466_16864 (EIF_REFERENCE Current)
{
	return (EIF_BOOLEAN) EIF_TRUE;
}

/* {ID_AS}.is_equal */
EIF_BOOLEAN F1466_16865 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("is_equal", 1465, Current, 0, 1, 23217);
	RTGC;
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_3_4_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ID_AS}.is_equivalent */
EIF_BOOLEAN F1466_16866 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("is_equivalent", 1465, Current, 0, 1, 23218);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) F1466_16865(Current, arg1);
}

void EIF_Minit790 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C16/id790.c <==
/*
 * Code for class ID_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "id790.h"
#include "eif_built_in.h"
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ID_AS}.initialize */
void F1466_17134 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("initialize", 1465, Current, 0, 1, 23643);
	RTGC;
	RTHOOK(1);
	tr1 = F612_5559(Current);
	F665_6880(RTCW(tr1), arg1);
	RTHOOK(2);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCV(F612_5559(Current))+ _LNGOFF_2_1_0_0_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_) = (EIF_INTEGER_32) ti4_1;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {ID_AS}.initialize_from_id */
void F1466_17135 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("initialize_from_id", 1465, Current, 0, 1, 23644);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_) = (EIF_INTEGER_32) arg1;
	RTHOOK(2);
	RTEE;
}

/* {ID_AS}.set_name */
void F1466_17136 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_name", 1465, Current, 0, 1, 23645);
	RTHOOK(1);
	F1466_17134(Current, arg1);
	RTHOOK(2);
	RTEE;
}

/* {ID_AS}.to_upper */
void F1466_17138 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_BOOLEAN loc4 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_8 tc1;
	EIF_CHARACTER_8 tc2;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("to_upper", 1465, Current, 4, 0, 23647);
	RTGC;
	RTHOOK(1);
	loc2 = *(EIF_REFERENCE *)(RTCV(F1466_17143(Current)));
	RTHOOK(2);
	loc3 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc2);
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 2L));
	for (;;) {
		RTHOOK(3);
		if ((EIF_BOOLEAN) (loc3 < ((EIF_INTEGER_32) 0L))) break;
		RTHOOK(4);
		/* INLINED CODE (SPECIAL.item) */
		tc2 = *((EIF_CHARACTER_8 *)RTCW(loc2) + (loc3));
		/* END INLINED CODE */
		loc1 = tc2;
		RTHOOK(5);
		tc1 = (EIF_CHARACTER_8) toupper(loc1);
		if ((EIF_BOOLEAN)(loc1 != tc1)) {
			RTHOOK(6);
			loc4 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(7);
			loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
		} else {
			RTHOOK(8);
			loc3--;
		}
	}
	RTHOOK(9);
	if (loc4) {
		RTHOOK(10);
		tr1 = F1466_17143(Current);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7182[Dtype(tr1)-1042])(RTCW(tr1));
		F1466_17134(Current, tr1);
	}
	RTHOOK(11);
	RTLE;
	RTEE;
}

/* {ID_AS}.to_lower */
void F1466_17139 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_BOOLEAN loc4 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_8 tc1;
	EIF_CHARACTER_8 tc2;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("to_lower", 1465, Current, 4, 0, 23648);
	RTGC;
	RTHOOK(1);
	loc2 = *(EIF_REFERENCE *)(RTCV(F1466_17143(Current)));
	RTHOOK(2);
	loc3 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc2);
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 2L));
	for (;;) {
		RTHOOK(3);
		if ((EIF_BOOLEAN) (loc3 < ((EIF_INTEGER_32) 0L))) break;
		RTHOOK(4);
		/* INLINED CODE (SPECIAL.item) */
		tc2 = *((EIF_CHARACTER_8 *)RTCW(loc2) + (loc3));
		/* END INLINED CODE */
		loc1 = tc2;
		RTHOOK(5);
		tc1 = (EIF_CHARACTER_8) tolower(loc1);
		if ((EIF_BOOLEAN)(loc1 != tc1)) {
			RTHOOK(6);
			loc4 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(7);
			loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
		} else {
			RTHOOK(8);
			loc3--;
		}
	}
	RTHOOK(9);
	if (loc4) {
		RTHOOK(10);
		tr1 = F1466_17143(Current);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7181[Dtype(tr1)-1042])(RTCW(tr1));
		F1466_17134(Current, tr1);
	}
	RTHOOK(11);
	RTLE;
	RTEE;
}

/* {ID_AS}.name_id */
EIF_INTEGER_32 F1466_17140 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_);
}


/* {ID_AS}.name_32 */
EIF_REFERENCE F1466_17141 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("name_32", 1465, Current, 0, 0, 23650);
	RTGC;
	RTHOOK(1);
	tr1 = F664_6866(Current);
	tr2 = F1466_17143(Current);
	Result = F1252_12016(RTCW(tr1), tr2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ID_AS}.name */
EIF_REFERENCE F1466_17143 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTEAA("name", 1465, Current, 0, 0, 23635);
	RTGC;
	RTHOOK(1);
	tr1 = F612_5559(Current);
	Result = F665_6877(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_));
	RTHOOK(2);
	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
		RTHOOK(3);
		Result = RTMS_EX_H("_Invalid_name",13,1140441701);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
}

/* {ID_AS}.process */
void F1466_17144 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process", 1465, Current, 0, 1, 23636);
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4022[Dtype(arg1)-507])(RTCW(arg1), Current);
	RTHOOK(2);
	RTEE;
}

/* {ID_AS}.is_detachable_expression */
EIF_BOOLEAN F1466_17146 (EIF_REFERENCE Current)
{
	return (EIF_BOOLEAN) EIF_TRUE;
}

/* {ID_AS}.is_equal */
EIF_BOOLEAN F1466_17147 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("is_equal", 1465, Current, 0, 1, 23639);
	RTGC;
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_3_4_);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_3_4_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ID_AS}.is_equivalent */
EIF_BOOLEAN F1466_17148 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("is_equivalent", 1465, Current, 0, 1, 23640);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) F1466_17147(Current, arg1);
}

void EIF_Minit790 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
